Offshore Substation Design Methodology
======================================

For details of the code implementation, please see
:doc:`Offshore Substation Design API <api_OffshoreSubstationDesign>`.

Overview
--------

The offshore substation design module in ORBIT is based on previous modeling
efforts undertaken by NREL, [#maness2017]_. A detailed description of the
model and its functionality can be found in the ORBIT technical
documentation (Coming soon!).

References
----------

.. [#maness2017] Michael Maness, Benjamin Maples, Aaron Smith,
    NREL Offshore Balance-of-System Model, 2017. https://www.nrel.gov/docs/fy17osti/66874.pdf
